##  Layout Modes
In landscape reports, the layout can be changed for different visualizations as well as for better condensation of information. To get to the different layout modes, simply use the Layout Mode drop-down menu and pick a mode.
![Different Layout Modes](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275067a27a4410148672d3d9e3b11782_LowRes.gif)
Different Layout Modes
